@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::date::str_alami_id;
 
-our $DATE = '2016-05-22'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2016-05-23'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -50,13 +50,13 @@ Data::Sah::Coerce::perl::date::str_alami_id - Coerce date from string parsed by
 
 =head1 VERSION
 
-This document describes version 0.003 of Data::Sah::Coerce::perl::date::str_alami_id (from Perl distribution Data-Sah-Coerce-perl-date-str_alami), released on 2016-05-22.
+This document describes version 0.004 of Data::Sah::Coerce::perl::date::str_alami_id (from Perl distribution Data-Sah-Coerce-perl-date-str_alami), released on 2016-05-23.
 
 =head1 DESCRIPTION
 
 The rule is not enabled by default. You can enable it in a schema using e.g.:
 
- ["array*", of=>"date", "x.perl.coerce_to"=>"DateTime", "x.perl.coerce_from"=>["str_alami_id"]]
+ ["array*", of=>"date", "x.perl.coerce_to"=>"DateTime", "x.perl.coerce_rules"=>["str_alami_id"]]
 
 =for Pod::Coverage ^(meta|coerce)$
 
